@@ -40,7 +40,7 @@ const char *hide_strings[] = {
     "Access to America Online", "time. By accessing",		/* AOL */
     "# Access and use restricted", "",				/* GANDI */
     "% The data in the WHOIS database of 1&1 Internet", "",
-    "The data in this whois database is", "",			/* enom */
+    "The data in this whois database is", NULL, /* enom, activeregistrar.com */
     "The Data in Moniker's WHOIS database", "of Moniker.",
     "The Data in OnlineNIC", "    By starting this query",
     "Interdomain's WHOIS", "DOES NOT SIGNIFY",
@@ -102,6 +102,7 @@ struct ip_del {
 };
 
 const struct ip_del ip_assign[] = {
+#include "ip_del_recovered.h"
 #include "ip_del.h"
     { 0, 0, NULL }
 };
