@@ -9,7 +9,7 @@ while (<>) {
 	s/^\s+//; s/\s+$//;
 	next if /^$/;
 
-	die "format error: $_" unless
+	die "format error: $_" if not
 		(my ($a, $b) = /^([\w\d\.-]+)\s+([\w\d\.:-]+|[A-Z]+\s+.*)$/);
 
 	$b =~ s/^W(?:EB)?\s+/\\x01/;
@@ -17,6 +17,6 @@ while (<>) {
 	$b = "\\x03" if $b eq 'NONE';
 	$b = "\\x08" if $b eq 'AFILIAS';
 	$b = "\\x0C" if $b eq 'ARPA';
-	print qq(    "$a",\t"$b",\n);
+	print qq|    "$a",\t"$b",\n|;
 }
 
